@@ -52,16 +52,12 @@ package com.openexchange.http.grizzly.osgi;
 import java.util.concurrent.ExecutorService;
 import org.glassfish.grizzly.comet.CometAddOn;
 import org.glassfish.grizzly.http.ajp.AjpAddOn;
-import org.glassfish.grizzly.http.HttpRequestPacket;
 import org.glassfish.grizzly.http.server.NetworkListener;
 import org.glassfish.grizzly.http.server.OXHttpServer;
 import org.glassfish.grizzly.http.server.ServerConfiguration;
 import org.glassfish.grizzly.nio.transport.TCPNIOTransport;
 import org.glassfish.grizzly.nio.transport.TCPNIOTransportBuilder;
-import org.glassfish.grizzly.websockets.WebSocket;
 import org.glassfish.grizzly.websockets.WebSocketAddOn;
-import org.glassfish.grizzly.websockets.WebSocketApplication;
-import org.glassfish.grizzly.websockets.WebSocketEngine;
 import org.osgi.framework.FrameworkEvent;
 import org.osgi.framework.FrameworkListener;
 import org.osgi.service.http.HttpService;
@@ -156,14 +152,26 @@ public class GrizzlyActivator extends HousekeepingActivator {
             serverConfiguration.setMaxRequestParameters(grizzlyConfig.getMaxRequestParameters());
 
             final NetworkListener networkListener = new NetworkListener("http-listener", grizzlyConfig.getHttpHost(), grizzlyConfig.getHttpPort());
+            networkListener.getKeepAlive().setIdleTimeoutInSeconds(-1);
 
+            /*-
+             * Set the maximum size of the POST body generated by an HTML form
+             * 
+             * Interferes with "com.openexchange.servlet.maxBodySize"
+             */
+            {
+                final ConfigurationService service = getService(ConfigurationService.class);
+                final int maxFormPostSize = null == service ? -1 : service.getIntProperty("com.openexchange.http.grizzly.maxFormPostSize", -1);
+                networkListener.setMaxFormPostSize(maxFormPostSize);
+            }
+            
             if (grizzlyConfig.isAJPEnabled()) {
                 if (LOG.isInfoEnabled()) {
                     LOG.info("Enabling AJP for Grizzly server.");
                 }
                 networkListener.registerAddOn(new AjpAddOn());
             }
-
+            
             TCPNIOTransport configuredTcpNioTransport = buildTcpNioTransport();
             networkListener.setTransport(configuredTcpNioTransport);
 
@@ -179,18 +187,18 @@ public class GrizzlyActivator extends HousekeepingActivator {
                     LOG.info("Enabling WebSockets for Grizzly server.");
                 }
                 networkListener.registerAddOn(new WebSocketAddOn());
-                WebSocketEngine.getEngine().register(new WebSocketApplication() {
-
-                    @Override
-                    public boolean isApplicationRequest(HttpRequestPacket request) {
-                        return "/echo".equals(request.getRequestURI());
-                    }
-
-                    @Override
-                    public void onMessage(WebSocket socket, String data) {
-                        socket.send(data);
-                    }
-                });
+//                WebSocketEngine.getEngine().register(new WebSocketApplication() {
+//
+//                    @Override
+//                    public boolean isApplicationRequest(HttpRequestPacket request) {
+//                        return "/echo".equals(request.getRequestURI());
+//                    }
+//
+//                    @Override
+//                    public void onMessage(WebSocket socket, String data) {
+//                        socket.send(data);
+//                    }
+//                });
             }
 
             if (grizzlyConfig.isCometEnabled()) {
