@@ -833,10 +833,8 @@ public final class TCPNIOTransport extends NIOTransport implements
                         final ByteBuffer directByteBuffer = directByteBufferRecord.strongRef;
                         read = readSimpleByteBuffer(tcpConnection,
                                 directByteBuffer, isSelectorThread);
-
                         directByteBuffer.flip();
-
-                        buffer = memoryManager.allocate(read);
+                        buffer = memoryManager.allocate(read > 0 ? read : 0);
                         buffer.put(directByteBuffer);
                     } finally {
                         releaseDirectByteBuffer(directByteBufferRecord);
